@@ -57,6 +57,7 @@ typedef enum {
 typedef struct {
   gchar   *dialog_text;
   MsgMode  mode;
+  gboolean no_wrap;
 } ZenityMsgData;
 
 typedef struct {
@@ -70,7 +71,7 @@ typedef struct {
 typedef struct {
   gchar   *dialog_text;
   gchar   *entry_text;
-  gboolean visible;
+  gboolean hide_text;
 } ZenityEntryData;
 
 typedef struct {
@@ -93,8 +94,10 @@ typedef struct {
   gboolean      checkbox;
   gboolean      radiobox;
   gchar        *separator;
+  gboolean      multi;
   gboolean      editable;
   gchar	       *print_column;
+  gchar	       *hide_column;
   const gchar **data;
 } ZenityTreeData;
 
